Index: trunk/IPs/systemC/processor/Morpheo/Script/execute.sh
===================================================================
--- trunk/IPs/systemC/processor/Morpheo/Script/execute.sh	(revision 124)
+++ trunk/IPs/systemC/processor/Morpheo/Script/execute.sh	(revision 126)
@@ -127,10 +127,10 @@
 	# Test if command is empty !
 	if test ! -z "${COMMAND[${CPT}]}"; then
+#	    echo "  * {"$(my_date)"} <${ID}> execute command [${CPT}] : ${COMMAND[${CPT}]}";
+	    echo "  * {"$(my_date)"} <${ID}> command [${CPT}] : execute";
 	    local PATH_CURRENT=${PWD};
             cd    ${PATH_WORK}        &> /dev/null;
 	    mkdir "Task_${CPT}"       &> /dev/null;
 	    cd    "Task_${CPT}"       &> /dev/null;
-#	    echo "  * {"$(my_date)"} <${ID}> execute command [${CPT}] : ${COMMAND[${CPT}]}";
-	    echo "  * {"$(my_date)"} <${ID}> execute command [${CPT}]";
             echo "id   : ${ID}"        >  ${OUTPUT_FILE_INFO};
             echo "host : ${HOSTNAME}" >>  ${OUTPUT_FILE_INFO};
@@ -143,4 +143,5 @@
 	    ./${OUTPUT_FILE_CMD}      &>  ${OUTPUT_FILE_OUT};
 	    cd    ${PATH_CURRENT}     &> /dev/null;
+	    echo "  * {"$(my_date)"} <${ID}> command [${CPT}] : done";
 	fi;
     done;
Index: trunk/IPs/systemC/processor/Morpheo/Script/execute_n.sh
===================================================================
--- trunk/IPs/systemC/processor/Morpheo/Script/execute_n.sh	(revision 124)
+++ trunk/IPs/systemC/processor/Morpheo/Script/execute_n.sh	(revision 126)
@@ -27,8 +27,9 @@
 function execute_n_usage ()
 {
-    echo "Usage     : ${0} path_word file [ nb_process ]";
+    echo "Usage     : ${0} path_word file_cmd file_cpt [ nb_process ]";
     echo "Arguments : ";
     echo " * path_work  : directory to execute command";
-    echo " * file       : list of command";
+    echo " * file_cmd   : list of command";
+    echo " * file_cpt   : file to control";
     echo " * nb_process : number of process (default (and maximum) is the number of processor)";
     echo "";
@@ -45,5 +46,5 @@
 function execute_n_test_usage ()
 {
-    if test ${#} -ne 2 -a ${#} -ne 3; then
+    if test ${#} -ne 3 -a ${#} -ne 4; then
 	execute_n_usage;
     fi;
@@ -76,5 +77,5 @@
     local    PATH_WORK=${1};
     local    FILE_CMD=${2};
-    local    FILE_CPT;
+    local    FILE_CPT=${3};
     local    FILE_CPU;
     local    ID="cpu-${HOSTNAME}-$$"
@@ -82,11 +83,10 @@
     execute_n_test_usage ${*};
 
-    if test ${#} -eq 3; then
-	if test ${3} -lt ${NB_PROCESS}; then
-	    NB_PROCESS=${3};
+    if test ${#} -eq 4; then
+	if test ${4} -lt ${NB_PROCESS}; then
+	    NB_PROCESS=${4};
 	fi;    
     fi;
 
-    FILE_CPT="${PATH_WORK}/control-"$(basename ${FILE_CMD});
     FILE_CPU="${PATH_WORK}/${ID}";
 

Index: trunk/IPs/systemC/processor/Morpheo/Script/distexe.sh
===================================================================
--- trunk/IPs/systemC/processor/Morpheo/Script/distexe.sh	(revision 124)
+++ trunk/IPs/systemC/processor/Morpheo/Script/distexe.sh	(revision 126)
@@ -7,5 +7,5 @@
 VERSION="1.0"
 
 # Need : test, echo, cd, dirname, basename, ssh
 
 #-----[ distexe_usage ]-------------------------------------
@@ -103,4 +103,6 @@
     fi;
 
+    local FILE_CPT="${PATH_EXE}/control-"$(basename ${FILE_CMD});
+    
     header;
     echo "  * {"$(my_date)"} <${HOSTNAME}> file : ${FILE_CMD}";
@@ -108,4 +110,6 @@
 
     local hosts="${DISTEXE_HOSTS}";
+    local -a commands;
+    local -i cpt=0;
 
     for line in ${hosts}; do
@@ -116,10 +120,26 @@
 
         # lunch service
-        local cmd="export MORPHEO_SCRIPT=${MORPHEO_SCRIPT};${MORPHEO_SCRIPT}/execute_n.sh ${PATH_EXE} ${FILE_CMD} ${nb_process};";
+        local cmd="export MORPHEO_SCRIPT=${MORPHEO_SCRIPT};${MORPHEO_SCRIPT}/execute_n.sh ${PATH_EXE} ${FILE_CMD} ${FILE_CPT} ${nb_process};";
         ssh ${host} ${cmd} &
+
+	commands[${cpt}]="${cmd}";
+	cpt=$((${cpt}+1));
     done;
 
     echo "  * {"$(my_date)"} <${HOSTNAME}> all hosts working";
 
+    cpt=0;
+    while test ${cpt} -lt ${#commands[*]}; do
+        local -i res=1
+
+        while test ${res} -ne 0; do
+            res=$(ps aux | grep -c "${commands[${cpt}]}");
+        done
+
+	cpt=$((${cpt}+1));
+    done;
+
+    echo "  * {"$(my_date)"} <${HOSTNAME}> all hosts is done";
+    rm ${FILE_CPT};
 }
 
@@ -7,5 +7,5 @@
 VERSION="1.0"
 
-# Need : test, echo, cd, dirname, basename, ssh
+# Need : test, echo, cd, dirname, basename, ssh, ps aux
 
 #-----[ distexe_usage ]-------------------------------------